create_master_raw_data: consolidate raw data into single file to simplify storage and...

Description Usage Arguments Value

Description

consolidate raw data into single file to simplify storage and loading

Usage

1
create_master_raw_data(dir, pattern = "weatherRasterList")

Arguments

dir

directory where raw data lives. Dir is the raw_data folder from inhereted from the get_raw_data

pattern

the pattern that identifies the raw data files

Value

nothing. It saves a single data file and deletes the other files.


one-acre-fund/arc2weather documentation built on May 16, 2019, 5:02 a.m.