Description Usage Arguments Value
consolidate raw data into single file to simplify storage and loading
1 | create_master_raw_data(dir, pattern = "weatherRasterList")
|
dir |
directory where raw data lives. Dir is the raw_data folder from inhereted from the get_raw_data |
pattern |
the pattern that identifies the raw data files |
nothing. It saves a single data file and deletes the other files.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.